:mod:`Customer`
===============

Models 
------
.. automodule:: lfs.customer.models

   .. autoclass:: Customer
   .. autoclass:: Address
   .. autoclass:: BankAccount   
   .. autoclass:: CreditCard   

Utils 
------   
.. automodule:: lfs.customer.utils

   .. autofunction:: get_or_create_customer
   .. autofunction:: create_customer
   .. autofunction:: get_customer
   .. autofunction:: update_customer_after_login